# Metadata for the widget EGG. Should leave it for the (unimplemented) widget
# tracker to track it

__PROJECT__ = 'tw.mootools'
__DESCRIPTION__ = 'ToscaWidgets wrapper for Mootools Javascript Toolkit'
__URL__ = 'http://toscawidgets.org/'
__VERSION__ = '0.9.8.1'
__AUTHOR__ = 'Christopher Perkins, Jonathan Schemoul'
__EMAIL__ = 'chris@percious.com, jonathan.schemoul@jmsinfor.com'
__COPYRIGHT__ = "Copyright 2008-2009 Christopher Perkins, Jonathan Schemoul"
__LICENSE__ = 'MIT'
