<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" 
                      "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<http xmlns="http://www.w3.org/1999/xhtml"
      xmlns:py="http://genshi.edgewall.org/"
      xmlns:xi="http://www.w3.org/2001/XInclude"
     >
<py:for each="item in widget_css">
	${item()}
</py:for>
<script type="text/javascript">
window.addEvent('domready', function() {
	${id} = new Sortables($('${id}'), {
		initialize: function(){
		}
	});
	${id}.addEvent('onComplete', function(){
		$onComplete
	});
});    
</script>
<ul id="$id">
	<li py:for="v in value" class="sortable_${v.id}">
		${v.value}
	</li>
</ul>
</http>