formcheckLanguage = {
	required: "Ezt a mezőt kötelező kitölteni.",
	alpha: "Ebben a mezőben csak betűk engedélyezettek.",
	alphanum: "Ebben a mezőben csak számok engedélyezettek.",
	nodigit: "Számok beírása nem lehetséges.",
	digit: "Csak számok beírása lehetséges.",
	digitmin: "A legkisebb lehetséges szám az %0.",
	digitltd: "Az értéknek %0 és %1 között kell lennie!",
	number: "Kérjük, adjon meg egy érvényes számot.",
	email: "Kérjük, adjon meg egy érvényes E-mail címet.",
	phone: "Kérjük, adjon meg egy érvényes telefonszámot.",
	url: "Kérjük, adjon meg egy érvényes internet címet.",
	
	confirm: "A mező eltér az %0.",
	differs: "Az értéknek az %0 képest eltérőnek kell lennie",
	length_str: "Das Feld ist verschieden von %0.",
	lengthmax: "Az érték nem helyes, a karakterek maximális száma %0.",
	lengthmin: "Az érték nem helyes, a karakterek minimális száma %0.",
	checkbox: "Kérjük aktiválja.",
	radios: "Kérjük, válasszon ki egy értéket.",
	select: "Kérjük, válasszon ki egy értéket."
}


