<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" 
                      "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<http xmlns="http://www.w3.org/1999/xhtml"
      xmlns:py="http://genshi.edgewall.org/"
      xmlns:xi="http://www.w3.org/2001/XInclude"
     >
<py:for each="item in moo_css">
	${item()}
</py:for>
<div  id="kwicks_container">
	<ul id="kwicks">
		<li py:for="v in value" id="kwick_${v.id}" class="kwick">
			<span>${v.value}</span>
		</li>
	</ul>
	<span class="clr"><!-- spanner --></span>
</div>
</http>