formcheckLanguage = {
	required: "Задължително за попълване поле.",
	alpha: "Това поле е само за букви.",
	alphanum: "Това поле е само за букви и числа.",
	nodigit: "Това поле не може да съдържа числа.",
	digit: "Моля въведете число.",
	digitmin: "Числото не може да бъде по-малко от %0",
	digitltd: "Числото трябва да е повече от %0 и по-малко от %1",
	number: "Моля въведете число.",
	email: "Моля въведете правилен email: <br /><span>Например yourname@domain.com</span>",
	phone: "Моля въведете правилен телефон.",
	url: "Моля въведете правилен адрес: <br /><span>Например http://www.domain.com</span>",
	
	confirm: "Полето трябва да е едно и също с поле %0",
	differs: "Числото трябва да се различава от %0",
	length_str: "Дължината на написаното трябва да е минимум %0 и максимум %1 символа",
	length_fix: "Дължината е неправилна, трябва да е точно %0 символа",
	lengthmax: "Попълнете полето, като внимавате да не превишите %0 символа",
	lengthmin: "Попълнете полето, като напишете поне %0 символа",
	checkbox: "Моля селектирайте чек-бокс опцията",
	radios: "Моля изберете един от вариантите",
	select: "Моля изберете един или повече от вариантите"
}