formcheckLanguage = {
	required: "Это поле обязательно для заполнения.",
	alpha: "Это поле может содержать только буквы.",
	alphanum: "Это поле может содержать только буквы и цифры.",
	nodigit: "Это поле не может содержать цифры.",
	digit: "Пожалуйста укажите число.",
	digitmin: "Число не может быть менее %0",
	digitltd: "Число должно быть более %0 и менее %1",
	number: "Пожалуйста укажите число.",
	email: "Пожалуйста укажите правильный email: <br /><span>Например yourname@domain.ru</span>",
	phone: "Пожалуйста укажите правильный телефон.",
	url: "Пожалуйста укажите правильный адрес url: <br /><span>Например http://www.domain.ru</span>",
	
	confirm: "Это поле не должно отличаться от поля %0",
	differs: "Число должно отличаться от %0",
	length_str: "Длина строки должна быть от %0 до %1 символов",
	length_fix: "The length is incorrect, it must be exactly %0 characters",
	lengthmax: "Заполните поле строкой, состоящей не более чем из %0 символов",
	lengthmin: "Заполните поле строкой, состоящей не менее чем из %0 символов",
	checkbox: "Пожалуйста поставьте галочку",
	radios: "Пожалуйста выберите из предложенных вариантов",
	select: "Пожалуйста выберите из предложенных вариантов"
}