

/* ******************************************************* */

.omnigrid{
	font-family: Verdana, Geneva, Arial, Helvetica, sans-serif;
	font-size: 11px;
	position: relative;
	border: 0px solid #eee;
	overflow:hidden; /* za debug iskljuci */
	color: #000;
	
}

.omnigrid div.hDivBox
{
	position:relative;
	overflow:hidden;
}


.omnigrid div.hDiv /* header div */
{
	background: #fafafa url(img/fhbg.gif) repeat-x bottom;
	position: relative;
	border: 1px solid #ccc;
	border-bottom: 0px;
	overflow: hidden;
}	

.omnigrid div.bDiv /* body div */
{
	border: 1px solid #ccc;
	border-top: 0px;
	background: #fff;
	overflow: auto;
	position: relative;
}

.omnigrid div.hDiv .th, .omnigrid  div.bDiv .td  /* common cell properties*/
{
	text-align: left;
	border-right: 1px solid #ddd;
	border-left: 1px solid #fff;
	vertical-align: top !important;
	
	display:inline-block;
	float:left;
	
	white-space:nowrap;
	overflow:hidden;
	/*
	padding-top:0;
	padding-bottom:0;*/
	padding-left:5px;
	
	cursor:pointer;
}

.omnigrid div.hDiv div.th{
	line-height:24px;
	
	border-bottom: 1px solid #CCC;
}

.omnigrid div.bDiv .td{
	line-height:24px;	
	/*background-color:red;*/
}

.omnigrid div.bDiv ul{
	margin:0;
	padding:0;
	border-bottom:1px solid #DDDDDD;
	overflow:hidden;
}

.omnigrid div.bDiv ul li{
	margin:0;
	padding:0;
	list-style:none;
	overflow:hidden;
}

.omnigrid li.erow /* alt rows */
{
	background-color: #f7f7f7;
	/*border-bottom: 1px solid #f7f7f7;*/
}

.omnigrid li.selected {
	background-color: #d9e6f4  !important;
	/*color: #fff;*/
}

.omnigrid li.over {
	background-color: #eaeff4;
	/*color: #fff;*/
}

/* ************************************** */
/* ************** Toolbar *************** */
/* ************************************** */
.omnigrid div.tDiv 
{
	background: #fafafa url(img/bg.gif) repeat-x top;
	position: relative;			
	border: 1px solid #ccc;
	border-bottom: 0px;
	overflow: hidden;
	
	height:25px;
}

.omnigrid div.fbutton
{
	margin-top:1px;
	float: left;
	display: block;
	cursor: pointer;
	padding: 1px;
}


.omnigrid div.fbutton div
{
	float: left;
	padding: 1px 3px;
}		

.omnigrid div.fbutton span
{
	float: left;
	display: block;
	padding: 3px;
}

.omnigrid div.fbutton:hover, .omnigrid div.fbutton.fbOver
{
	padding: 0px;
	border: 1px solid #ccc;
}

.omnigrid div.fbutton:hover div, .omnigrid div.fbutton.fbOver div
{
	padding: 0px 2px;
	border-left: 1px solid #fff;
	border-top: 1px solid #fff;
	border-right: 1px solid #eee;
	border-bottom: 1px solid #eee;
}		

.omnigrid div.btnseparator
{
	float: left;
	height: 22px;
	border-left: 1px solid #ccc;
	border-right: 1px solid #fff;
	margin: 2px;
}

/* end toolbar*/

/* ************************************** */

/* ************************************** */
/* ************** Filter **************** */
/* ************************************** */

.omnigrid li.hide {
	display: none;
}

.omnigrid li.filter {

}

/* ************************************** */
/* ************** Columns size drag ***** */
/* ************************************** */

.omnigrid div.cDrag
{
	float: left;
	position: absolute;
	z-index: 2;
	overflow: visible;
}

.omnigrid div.cDrag div
{
	float: left;
	background: none;
	display: block;
	position: absolute;
	height: 24px;
	width: 5px;
	cursor: col-resize;

}

.omnigrid div.cDrag div.dragging
{
	background: url(img/line.gif) repeat-y 2px center;
}

/* ************************************** */
/* ************** Sort ****************** */
/* ************************************** */

.omnigrid div.hDiv div.DESC
{
	background: url(img/dn.png) no-repeat center top;
	border-bottom: 1px solid orange !important;
}	

.omnigrid div.hDiv  div.ASC
{
	background: url(img/up.png) no-repeat center top;
	border-bottom: 1px solid orange !important;
}	


.sortedASC {
	background-image: url(images/arrow_down.gif);
	background-repeat:no-repeat;
	
	background-position: right center;
}

.sortedDESC {
	background-image: url(images/arrow_up.gif);
	background-repeat:no-repeat;
	
	background-position: right center;
}

