/* Calendar Header/Controls */
.mooECal{margin:0; padding:0; width:600px; border:1px solid #999; border-left:none; text-align:center; border-collapse:separate; font-family:Arial, Helvetica, sans-serif;}
.mooECal li, .mooECal ul{list-style:none; display:inline; margin:0; padding:0;}
.thControls, .ulControls{text-align:left;}
.thControls{ border-bottom:1px solid #999; border-left:1px solid #999;}
.mooECal .liHeaderCal{font-size:1.0em; float:right; width:52%; text-align:center; margin-right:2%;} /* date range of current view */
.aPrevCal,.aNextCal{text-decoration:none; font-size:1.2em;} /* left/right nav arrow */
.mooECal .liNextCal{float:right;}
.mooECal .liLoading{font-size:0.8em; color:#999; letter-spacing:0.3em; margin-left:2%;}/* "loading..." text */
/* month, week, day view links*/
.ulViewPicker li{float:right;}
.aViewCal{text-decoration:none; font-size:10px; margin-right:1.2em; color:#999;} 
.aViewCal:hover{text-decoration:underline;}
/* mon, tues, wed ... row */
.mooECal tr.dowRow th{border-left:1px solid #999; font-size:0.6em; text-align:center;}
.mooECal tr.dowRow th li{float:left; width:14.28%;}


/* Calendar Body */
.monthWeek{overflow:hidden;}
.monthDay,.weekDay,.dayDay{border:1px solid #999; border-right:none; border-bottom:none; width:14%; text-align:left; vertical-align:top;}
.dayDay{width:100%;}
.mooECal td.hover{background-color:#FFD;} /* color when hovering a day */
.mooECal td.selected{background-color:#EEF;} /* color for the selected day */
.mooECal td span{color:#333; font-size:0.8em;} /* day of the month (1-31) */
.mooECal td div{font-size:10px; color:#009; height:12px; overflow:hidden; cursor:default;}
.mooECal td div.fullEvent{height:auto; overflow:auto; font-size:14px; border-top:1px solid #CCC;}
/* tips styling */
.tip {color: #fff; z-index: 13000; background-color:#666; -moz-border-radius: 3px; -webkit-border-radius: 3px;}
.tip-title {font-weight: bold;font-size: 11px;margin: 0;padding: 8px 8px 4px;}
.tip-text {font-size: 11px;padding: 4px 8px 8px;}