formcheckLanguage = {
	required: "必須項目です",
	alpha: "アルファベットを入力してください",
	alphanum: "アルファベットと数字を入力してください",
	nodigit: "桁の数字は使用できません",
	digit: "有効な数字を入力してください",
	digitmin: "数字は少なくとも%0で入力してください",
	digitltd: "数字は%0と%1の間で入力してください",
	number: "有効な数字を入力してください",
	email: "有効なE-mailアドレスを入力してください",
	phone: "有効な電話番号を入力してください",
	url: "有効なURLを入力してください",
	
	confirm: "これは%0と異なります",
	differs: "これは%0と異なるものを入力してください",
	length_str: "長さが有効ではありません。%0と%1の間で入力してください",
	length_fix: "The length is incorrect, it must be exactly %0 characters",
	lengthmax: "長さが有効ではありません。最大%0で入力してください",
	lengthmin: "長さが有効ではありません。最小%0で入力してください",
	checkbox: "ボックスを確認してください",
	radios: "項目を選択してください",
	select: "項目を選択してください"
}
