<div xmlns="http://www.w3.org/1999/xhtml" 
     xmlns:py="http://genshi.edgewall.org/">
    <script type="text/javascript">
    	window.addEvent('domready', function() {
			new DatePicker($('${id}'));
		});
    </script>
    <input type="text" id="${id}" class="${css_class}" name="${name}" 
           value="${strdate}" py:attrs="attrs"/>
</div>
